@@ -5,8 +5,6 @@ from pathlib import Path
 from sys import exit, stderr
 from typing import List, Optional
 
-from ycontract import contract
-
 from exclock.sound_player import Player
 from exclock.util import (
     DEFAULT_RING_FILENAME,
@@ -20,7 +18,6 @@ from exclock.util import (
 )
 
 
-@contract(returns=lambda res: res is None or res >= 0)
 def get_spend_sec(time_: str) -> Optional[int]:
     if is_specific_time_str(time_):
         now_ = datetime.now()
